RiveIntegration class sealed

Create Rive integration based on the resolved version.

Inheritance
Implementers

Constructors

RiveIntegration(String packageName, {Version? resolvedVersion, VersionConstraint? resolvedVersionConstraint})
factory

Properties

className String
no setteroverride
classOutput String
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
isConstConstructor bool
no setteroverride
isEnabled bool
getter/setter pairinherited
isPackage bool
latefinalinherited
packageExpression String?
no setter
packageName String
The package name for this asset. If empty, the asset is not in a package.
finalinherited
parseMetadata bool
finalinherited
requiredImports List<Import>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

classInstantiate(AssetType asset) String
inherited
isSupport(AssetType asset) bool
Is this asset type supported by this integration?
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited