RiveIntegrationClassic class final

Rive integration for versions before 0.14.0.

Inheritance

Constructors

RiveIntegrationClassic(String packageName)

Properties

className String
no setterinherited
classOutput String
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isConstConstructor bool
no setterinherited
isEnabled bool
getter/setter pairinherited
isPackage bool
latefinalinherited
packageExpression String?
no setterinherited
packageName String
The package name for this asset. If empty, the asset is not in a package.
finalinherited
parseMetadata bool
finalinherited
requiredImports List<Import>
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

classInstantiate(AssetType asset) String
inherited
isSupport(AssetType asset) bool
Is this asset type supported by this integration?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited